# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/date_interval.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/type/shared/v1/date_interval.proto\x12 systemathics.apis.type.shared.v1\x1a\x16google/type/date.proto\"n\n\x0c\x44\x61teInterval\x12\x30\n\nstart_date\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\tstartDate\x12,\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x07\x65ndDateB\xde\x01\n$com.systemathics.apis.type.shared.v1B\x11\x44\x61teIntervalProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.date_interval_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\021DateIntervalProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_DATEINTERVAL']._serialized_start=114
  _globals['_DATEINTERVAL']._serialized_end=224
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday/v2/set_intraday_scalar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2
from systemathics.apis.type.shared.v2 import set_data_mode_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_set__data__mode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@systemathics/apis/services/intraday/v2/set_intraday_scalar.proto\x12&systemathics.apis.services.intraday.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/type/datetime.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\x1a\x34systemathics/apis/type/shared/v2/set_data_mode.proto\"\xcf\x01\n\x18SetIntradayScalarRequest\x12S\n\x04info\x18\x01 \x01(\x0b\x32=.systemathics.apis.services.intraday.v2.SetIntradayScalarInfoH\x00R\x04info\x12S\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32=.systemathics.apis.services.intraday.v2.SetIntradayScalarDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\xca\x01\n\x1a\x43learIntradayScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields\"\x88\x02\n\x15SetIntradayScalarInfo\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields\x12\x41\n\x04mode\x18\x04 \x01(\x0e\x32-.systemathics.apis.type.shared.v2.SetDataModeR\x04mode\"^\n\x15SetIntradayScalarData\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta2\xac\x02\n\x18SetIntradayScalarService\x12\x85\x01\n\x11SetIntradayScalar\x12@.systemathics.apis.services.intraday.v2.SetIntradayScalarRequest\x1a\x16.google.protobuf.Empty\"\x14\x82\xd3\xe4\x93\x02\x0e\"\x0c/v2/intraday(\x01\x12\x87\x01\n\x13\x43learIntradayScalar\x12\x42.systemathics.apis.services.intraday.v2.ClearIntradayScalarRequest\x1a\x16.google.protobuf.Empty\"\x14\x82\xd3\xe4\x93\x02\x0e*\x0c/v2/intradayB\x81\x02\n*com.systemathics.apis.services.intraday.v2B\x16SetIntradayScalarProtoP\x01\xa2\x02\x04SASI\xaa\x02&Systemathics.Apis.Services.Intraday.V2\xca\x02&Systemathics\\Apis\\Services\\Intraday\\V2\xe2\x02\x32Systemathics\\Apis\\Services\\Intraday\\V2\\GPBMetadata\xea\x02*Systemathics::Apis::Services::Intraday::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday.v2.set_intraday_scalar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.systemathics.apis.services.intraday.v2B\026SetIntradayScalarProtoP\001\242\002\004SASI\252\002&Systemathics.Apis.Services.Intraday.V2\312\002&Systemathics\\Apis\\Services\\Intraday\\V2\342\0022Systemathics\\Apis\\Services\\Intraday\\V2\\GPBMetadata\352\002*Systemathics::Apis::Services::Intraday::V2'
  _globals['_SETINTRADAYSCALARSERVICE'].methods_by_name['SetIntradayScalar']._options = None
  _globals['_SETINTRADAYSCALARSERVICE'].methods_by_name['SetIntradayScalar']._serialized_options = b'\202\323\344\223\002\016\"\014/v2/intraday'
  _globals['_SETINTRADAYSCALARSERVICE'].methods_by_name['ClearIntradayScalar']._options = None
  _globals['_SETINTRADAYSCALARSERVICE'].methods_by_name['ClearIntradayScalar']._serialized_options = b'\202\323\344\223\002\016*\014/v2/intraday'
  _globals['_SETINTRADAYSCALARREQUEST']._serialized_start=480
  _globals['_SETINTRADAYSCALARREQUEST']._serialized_end=687
  _globals['_CLEARINTRADAYSCALARREQUEST']._serialized_start=690
  _globals['_CLEARINTRADAYSCALARREQUEST']._serialized_end=892
  _globals['_SETINTRADAYSCALARINFO']._serialized_start=895
  _globals['_SETINTRADAYSCALARINFO']._serialized_end=1159
  _globals['_SETINTRADAYSCALARDATA']._serialized_start=1161
  _globals['_SETINTRADAYSCALARDATA']._serialized_end=1255
  _globals['_SETINTRADAYSCALARSERVICE']._serialized_start=1258
  _globals['_SETINTRADAYSCALARSERVICE']._serialized_end=1558
# @@protoc_insertion_point(module_scope)
